
#ifndef KDEVPLATFORMTESTS_EXPORT_H
#define KDEVPLATFORMTESTS_EXPORT_H

#ifdef KDEVPLATFORMTESTS_STATIC_DEFINE
#  define KDEVPLATFORMTESTS_EXPORT
#  define KDEVPLATFORMTESTS_NO_EXPORT
#else
#  ifndef KDEVPLATFORMTESTS_EXPORT
#    ifdef KDevPlatformTests_EXPORTS
        /* We are building this library */
#      define KDEVPLATFORMTESTS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define KDEVPLATFORMTESTS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef KDEVPLATFORMTESTS_NO_EXPORT
#    define KDEVPLATFORMTESTS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef KDEVPLATFORMTESTS_DEPRECATED
#  define KDEVPLATFORMTESTS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KDEVPLATFORMTESTS_DEPRECATED_EXPORT
#  define KDEVPLATFORMTESTS_DEPRECATED_EXPORT KDEVPLATFORMTESTS_EXPORT KDEVPLATFORMTESTS_DEPRECATED
#endif

#ifndef KDEVPLATFORMTESTS_DEPRECATED_NO_EXPORT
#  define KDEVPLATFORMTESTS_DEPRECATED_NO_EXPORT KDEVPLATFORMTESTS_NO_EXPORT KDEVPLATFORMTESTS_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef KDEVPLATFORMTESTS_NO_DEPRECATED
#    define KDEVPLATFORMTESTS_NO_DEPRECATED
#  endif
#endif

#endif /* KDEVPLATFORMTESTS_EXPORT_H */
