// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KDEVELOP_VERSION_H
#define KDEVELOP_VERSION_H

#define KDEVELOP_VERSION_STRING "5.9.220801"
#define KDEVELOP_VERSION_MAJOR 5
#define KDEVELOP_VERSION_MINOR 9
#define KDEVELOP_VERSION_PATCH 220801
#define KDEVELOP_VERSION ((5<<16)|(9<<8)|(220801))

#endif
